==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportInstanceDocument.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * ReportInstanceDocument
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class ReportInstanceDocument extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** ReportInstanceDocument attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** description column */
        public static final String DESCRIPTION = "description";
        /** documentRepositoryId column */
        public static final String DOCUMENTREPOSITORYID = "documentRepositoryId";
        /** publicVisibility column */
        public static final String PUBLICVISIBILITY = "publicVisibility";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("description");
            list.add("documentRepositoryId");
            list.add("publicVisibility");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * reportInstance relation.
         *
         * @return the reportInstance bean relations attributes.
         */
        public ReportInstance.Relations reportInstance()
        {
			ReportInstance c = new ReportInstance();
            return c.new Relations(this.buildPath("reportInstance"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the DESCRIPTION path.
         *
         * @return the path
         */
        public String DESCRIPTION()
        {
            return buildPath(Fields.DESCRIPTION);
        }
		/**
         * the DOCUMENTREPOSITORYID path.
         *
         * @return the path
         */
        public String DOCUMENTREPOSITORYID()
        {
            return buildPath(Fields.DOCUMENTREPOSITORYID);
        }
		/**
         * the PUBLICVISIBILITY path.
         *
         * @return the path
         */
        public String PUBLICVISIBILITY()
        {
            return buildPath(Fields.PUBLICVISIBILITY);
        }
    }
	
	/** The dummy obj. */
    private static ReportInstanceDocument dummyObj = new ReportInstanceDocument();

	/**
     * Get ReportInstanceDocument Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    @Override
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("reportInstance".equalsIgnoreCase(attributeName))
            return reportInstance;
        if ("description".equalsIgnoreCase(attributeName))
            return description;
        if ("documentRepositoryId".equalsIgnoreCase(attributeName))
            return documentRepositoryId;
        if ("publicVisibility".equalsIgnoreCase(attributeName))
            return publicVisibility;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("reportInstance".equalsIgnoreCase(attributeName))
            reportInstance = (ReportInstance)attributeValue;
        if ("description".equalsIgnoreCase(attributeName))
            description = (String)attributeValue;
        if ("documentRepositoryId".equalsIgnoreCase(attributeName))
            documentRepositoryId = (Long)attributeValue;
        if ("publicVisibility".equalsIgnoreCase(attributeName))
            publicVisibility = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** reportInstance private attribute */
    private ReportInstance reportInstance;

    /** description private attribute */
    private String description;

    /** documentRepositoryId private attribute */
    private Long documentRepositoryId;

    /** publicVisibility private attribute */
    private String publicVisibility;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ReportInstanceDocument() {
    }

	/** 
	 * minimal constructor
	 *
     * @param reportInstance
    }
	 */
    public ReportInstanceDocument(ReportInstance reportInstance) {
        this.reportInstance = reportInstance;
    }

    /**
     * full constructor
	 *
     * @param reportInstance
     * @param description
     * @param documentRepositoryId
     * @param publicVisibility
     */
    public ReportInstanceDocument(ReportInstance reportInstance, String description, Long documentRepositoryId, String publicVisibility) {
        this.reportInstance = reportInstance;
        this.description = description;
        this.documentRepositoryId = documentRepositoryId;
        this.publicVisibility = publicVisibility;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * reportInstance getter method
     *
     * @return reportInstance method
     */
    public ReportInstance getReportInstance() {
        return this.reportInstance;
    }
    
    /**       
     * reportInstance setter method
     *
     * @param reportInstance
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setReportInstance(ReportInstance reportInstance) {
        this.reportInstance = reportInstance;
        
        return this;
    }
    /**       
     * description getter method
     *
     * @return description method
     */
    public String getDescription() {
        return this.description;
    }
    
    /**       
     * description setter method
     *
     * @param description
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setDescription(String description) {
        this.description = description;
        
        return this;
    }
    /**       
     * documentRepositoryId getter method
     *
     * @return documentRepositoryId method
     */
    public Long getDocumentRepositoryId() {
        return this.documentRepositoryId;
    }
    
    /**       
     * documentRepositoryId setter method
     *
     * @param documentRepositoryId
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setDocumentRepositoryId(Long documentRepositoryId) {
        this.documentRepositoryId = documentRepositoryId;
        
        return this;
    }
    /**       
     * publicVisibility getter method
     *
     * @return publicVisibility method
     */
    public String getPublicVisibility() {
        return this.publicVisibility;
    }
    
    /**       
     * publicVisibility setter method
     *
     * @param publicVisibility
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setPublicVisibility(String publicVisibility) {
        this.publicVisibility = publicVisibility;
        
        return this;
    }

    /**
     * Creates a String representation of the ReportInstanceDocument object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("description").append("='").append(getDescription()).append("' ");			
        buffer.append("documentRepositoryId").append("='").append(getDocumentRepositoryId()).append("' ");			
        buffer.append("publicVisibility").append("='").append(getPublicVisibility()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ReportInstanceDocument object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ReportInstanceDocument other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("description".equalsIgnoreCase(attributeName))
        	this.description = attributeValue;

        if ("documentRepositoryId".equalsIgnoreCase(attributeName))
            this.documentRepositoryId = Long.valueOf(attributeValue);

        if ("publicVisibility".equalsIgnoreCase(attributeName))
        	this.publicVisibility = attributeValue;

    }


}

==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportInstanceDocument.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * ReportInstanceDocument
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class ReportInstanceDocument extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<ReportInstanceDocument> {

    /** ReportInstanceDocument attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** description column */
        public static final String DESCRIPTION ="description";
        /** documentRepositoryId column */
        public static final String DOCUMENTREPOSITORYID ="documentRepositoryId";
        /** publicVisibility column */
        public static final String PUBLICVISIBILITY ="publicVisibility";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("description");
            list.add("documentRepositoryId");
            list.add("publicVisibility");

            return list;
        }
    }

    /** Field attributes */
    public static ReportInstanceDocumentFieldAttributes FieldAttributes=new ReportInstanceDocumentFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ReportInstanceDocumentFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * reportInstance relation.
         *
         * @return the reportInstance bean relations attributes.
         */
        public ReportInstance.Relations reportInstance()
        {
            ReportInstance c = new ReportInstance();
            return c.new Relations(this.buildPath("reportInstance"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the DESCRIPTION path.
         *
         * @return the path
         */
        public String DESCRIPTION()
        {
            return buildPath(Fields.DESCRIPTION);
        }
        /**
         * the DOCUMENTREPOSITORYID path.
         *
         * @return the path
         */
        public String DOCUMENTREPOSITORYID()
        {
            return buildPath(Fields.DOCUMENTREPOSITORYID);
        }
        /**
         * the PUBLICVISIBILITY path.
         *
         * @return the path
         */
        public String PUBLICVISIBILITY()
        {
            return buildPath(Fields.PUBLICVISIBILITY);
        }
    }

    /** The dummy obj. */
    private static ReportInstanceDocument dummyObj=new ReportInstanceDocument();

    /**
     * Get ReportInstanceDocument Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<ReportInstanceDocument> getDataSet()
    {
        return new HibernateDataSet<ReportInstanceDocument>(ReportInstanceDocument.class, HibernateUtil.getSessionFactory("DIFRepository"),
            ReportInstanceDocument.getPKFieldListAsString(), ReportInstanceDocument.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<ReportInstanceDocument> getDataSetInstance()
    {
        return new ReportInstanceDocument().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("reportInstance".equalsIgnoreCase(attributeName))
            return reportInstance;
        if("description".equalsIgnoreCase(attributeName))
            return description;
        if("documentRepositoryId".equalsIgnoreCase(attributeName))
            return documentRepositoryId;
        if("publicVisibility".equalsIgnoreCase(attributeName))
            return publicVisibility;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("reportInstance".equalsIgnoreCase(attributeName))
            reportInstance =(ReportInstance)attributeValue;
        if("description".equalsIgnoreCase(attributeName))
            description =(String)attributeValue;
        if("documentRepositoryId".equalsIgnoreCase(attributeName))
            documentRepositoryId =(Long)attributeValue;
        if("publicVisibility".equalsIgnoreCase(attributeName))
            publicVisibility =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** reportInstance private attribute */
    private ReportInstance reportInstance;

    /** description private attribute */
    private String description;

    /** documentRepositoryId private attribute */
    private Long documentRepositoryId;

    /** publicVisibility private attribute */
    private String publicVisibility;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ReportInstanceDocument() {
    }

	/** 
	 * minimal constructor
	 *
     * @param reportInstance the reportInstance
    }
	 */
    public ReportInstanceDocument(ReportInstance reportInstance) {
        this.reportInstance = reportInstance;
    }

    /**
     * full constructor
	 *
     * @param reportInstance the reportInstance
     * @param description the description
     * @param documentRepositoryId the documentRepositoryId
     * @param publicVisibility the publicVisibility
     */
    public ReportInstanceDocument(ReportInstance reportInstance, String description, Long documentRepositoryId, String publicVisibility) {
        this.reportInstance = reportInstance;
        this.description = description;
        this.documentRepositoryId = documentRepositoryId;
        this.publicVisibility = publicVisibility;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * reportInstance getter method
     *
     * @return reportInstance method
     */
    public ReportInstance getReportInstance() {
        return this.reportInstance;
    }
    
    /**       
     * reportInstance setter method
     *
     * @param reportInstance the reportInstance
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setReportInstance(ReportInstance reportInstance) {
        this.reportInstance = reportInstance;
        
        return this;
    }
    /**       
     * description getter method
     *
     * @return description method
     */
    public String getDescription() {
        return this.description;
    }
    
    /**       
     * description setter method
     *
     * @param description the description
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setDescription(String description) {
        this.description = description;
        
        return this;
    }
    /**       
     * documentRepositoryId getter method
     *
     * @return documentRepositoryId method
     */
    public Long getDocumentRepositoryId() {
        return this.documentRepositoryId;
    }
    
    /**       
     * documentRepositoryId setter method
     *
     * @param documentRepositoryId the documentRepositoryId
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setDocumentRepositoryId(Long documentRepositoryId) {
        this.documentRepositoryId = documentRepositoryId;
        
        return this;
    }
    /**       
     * publicVisibility getter method
     *
     * @return publicVisibility method
     */
    public String getPublicVisibility() {
        return this.publicVisibility;
    }
    
    /**       
     * publicVisibility setter method
     *
     * @param publicVisibility the publicVisibility
     *
     * @return ReportInstanceDocument modified instance
     */
    public ReportInstanceDocument setPublicVisibility(String publicVisibility) {
        this.publicVisibility = publicVisibility;
        
        return this;
    }

    /**
     * Creates a String representation of the ReportInstanceDocument object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("description").append("='").append(getDescription()).append("' ");			
        buffer.append("documentRepositoryId").append("='").append(getDocumentRepositoryId()).append("' ");			
        buffer.append("publicVisibility").append("='").append(getPublicVisibility()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ReportInstanceDocument object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ReportInstanceDocument other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("description".equalsIgnoreCase(attributeName))
        	this.description = attributeValue;

        if ("documentRepositoryId".equalsIgnoreCase(attributeName))
            this.documentRepositoryId = Long.valueOf(attributeValue);

        if ("publicVisibility".equalsIgnoreCase(attributeName))
        	this.publicVisibility = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static ReportInstanceDocument getProxy(Session session, Long id)
    {
        return(ReportInstanceDocument)session.load(ReportInstanceDocument.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static ReportInstanceDocument getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportInstanceDocument result = (ReportInstanceDocument)session.load(ReportInstanceDocument.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static ReportInstanceDocument getInstance(Session session, Long id)
    {
        return(ReportInstanceDocument)session.get(ReportInstanceDocument.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static ReportInstanceDocument getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportInstanceDocument result = (ReportInstanceDocument)session.get(ReportInstanceDocument.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
